==> react-image-annotate-2.0.13.tgz: package/MetadataEditorSidebarBox/index.js <==
import React, { memo } from "react";
import SidebarBoxContainer from "../SidebarBoxContainer";
import DescriptionIcon from "@mui/icons-material/Description";
import { styled } from "@mui/material/styles";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import { grey } from "@mui/material/colors";
var MetadataItemDiv = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {
    display: "flex",
    flexDirection: "column",
    marginBottom: "1rem",
    "& > label": {
      fontSize: "1rem",
      marginBottom: ".5rem",
      textTransform: "capitalize"
    }
  };
});

var MetadataItem = function MetadataItem(_ref2) {
  var name = _ref2.name,
      value = _ref2.value,
      imageIndex = _ref2.imageIndex,
      onChange = _ref2.onChange;

  var handleChange = function handleChange(e) {
    e.preventDefault();
    var _e$target = e.target,
        name = _e$target.name,
        value = _e$target.value;
    onChange({
      name: name,
      value: value,
      imageIndex: imageIndex
    });
  };

  return React.createElement(MetadataItemDiv, null, React.createElement("label", {
    for: name
  }, name), React.createElement("input", {
    type: "text",
    value: value,
    name: name,
    onChange: handleChange
  }));
};

var MetadataList = function MetadataList(_ref3) {
  var title = _ref3.title,
      metadata = _ref3.metadata,
      imageIndex = _ref3.imageIndex,
      onMetadataChange = _ref3.onMetadataChange;
  return React.createElement("div", null, React.createElement("h2", null, title), metadata.map(function (_ref4) {
    var key = _ref4.key,
        value = _ref4.value;
    return React.createElement(MetadataItem, {
      name: key,
      value: value,
      imageIndex: imageIndex,
      onChange: onMetadataChange
    });
  }));
};

var theme = createTheme();
var DivContainer = styled("div")(function (_ref5) {
  var theme = _ref5.theme;
  return {
    paddingLeft: 16,
    paddingRight: 16,
    fontSize: 12,
    "& h1": {
      fontSize: 18
    },
    "& h2": {
      fontSize: 14
    },
    "& h3": {
      fontSize: 12
    },
    "& h4": {
      fontSize: 12
    },
    "& h5": {
      fontSize: 12
    },
    "& h6": {
      fontSize: 12
    },
    "& p": {
      fontSize: 12
    },
    "& a": {},
    "& img": {
      width: "100%"
    }
  };
});
export var MetadataEditorSidebarBox = function MetadataEditorSidebarBox(_ref6) {
  var _state$images$state$s;

  var state = _ref6.state,
      onMetadataChange = _ref6.onMetadataChange;
  return React.createElement(ThemeProvider, {
    theme: theme
  }, React.createElement(SidebarBoxContainer, {
    title: "Metadata",
    icon: React.createElement(DescriptionIcon, {
      style: {
        color: grey[700]
      }
    }),
    expandedByDefault: true
  }, React.createElement(DivContainer, null, React.createElement(MetadataList, {
    title: "Global",
    metadata: state.metadata,
    onMetadataChange: onMetadataChange
  }), (state === null || state === void 0 ? void 0 : (_state$images$state$s = state.images[state.selectedImage]) === null || _state$images$state$s === void 0 ? void 0 : _state$images$state$s.metadata) && React.createElement(MetadataList, {
    title: "Local",
    metadata: state.images[state.selectedImage].metadata,
    imageIndex: state.selectedImage,
    onMetadataChange: onMetadataChange
  }))));
};
export default memo(MetadataEditorSidebarBox);

==> react-image-annotate-2.0.26.tgz: package/MetadataEditorSidebarBox/index.js <==
import React, { memo } from "react";
import SidebarBoxContainer from "../SidebarBoxContainer";
import DescriptionIcon from "@mui/icons-material/Description";
import { styled } from "@mui/material/styles";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import { grey } from "@mui/material/colors";
var MetadataItemDiv = styled("div")(function (_ref) {
  var theme = _ref.theme;
  return {
    display: "flex",
    flexDirection: "column",
    marginBottom: "1rem",
    "& > label": {
      fontSize: "1rem",
      marginBottom: ".5rem",
      textTransform: "capitalize"
    }
  };
});

var MetadataItem = function MetadataItem(_ref2) {
  var name = _ref2.name,
      value = _ref2.value,
      imageIndex = _ref2.imageIndex,
      onChange = _ref2.onChange;

  var handleChange = function handleChange(e) {
    e.preventDefault();
    var _e$target = e.target,
        name = _e$target.name,
        value = _e$target.value;
    onChange({
      name: name,
      value: value,
      imageIndex: imageIndex
    });
  };

  return React.createElement(MetadataItemDiv, null, React.createElement("label", {
    for: name
  }, name), React.createElement("input", {
    type: "text",
    value: value,
    name: name,
    onChange: handleChange
  }));
};

var MetadataList = function MetadataList(_ref3) {
  var title = _ref3.title,
      metadata = _ref3.metadata,
      imageIndex = _ref3.imageIndex,
      onMetadataChange = _ref3.onMetadataChange;
  return React.createElement("div", null, React.createElement("h2", null, title), metadata && metadata.map(function (_ref4) {
    var key = _ref4.key,
        value = _ref4.value;
    return React.createElement(MetadataItem, {
      name: key,
      value: value,
      imageIndex: imageIndex,
      onChange: onMetadataChange
    });
  }));
};

var theme = createTheme();
var DivContainer = styled("div")(function (_ref5) {
  var theme = _ref5.theme;
  return {
    paddingLeft: 16,
    paddingRight: 16,
    fontSize: 12,
    "& h1": {
      fontSize: 18
    },
    "& h2": {
      fontSize: 14
    },
    "& h3": {
      fontSize: 12
    },
    "& h4": {
      fontSize: 12
    },
    "& h5": {
      fontSize: 12
    },
    "& h6": {
      fontSize: 12
    },
    "& p": {
      fontSize: 12
    },
    "& a": {},
    "& img": {
      width: "100%"
    }
  };
});
export var MetadataEditorSidebarBox = function MetadataEditorSidebarBox(_ref6) {
  var _state$images$state$s;

  var state = _ref6.state,
      onMetadataChange = _ref6.onMetadataChange;
  return React.createElement(ThemeProvider, {
    theme: theme
  }, React.createElement(SidebarBoxContainer, {
    title: "Metadata",
    icon: React.createElement(DescriptionIcon, {
      style: {
        color: grey[700]
      }
    }),
    expandedByDefault: true
  }, React.createElement(DivContainer, null, React.createElement(MetadataList, {
    title: "Global",
    metadata: state.metadata,
    onMetadataChange: onMetadataChange
  }), (state === null || state === void 0 ? void 0 : (_state$images$state$s = state.images[state.selectedImage]) === null || _state$images$state$s === void 0 ? void 0 : _state$images$state$s.metadata) && React.createElement(MetadataList, {
    title: "Local",
    metadata: state.images[state.selectedImage].metadata,
    imageIndex: state.selectedImage,
    onMetadataChange: onMetadataChange
  }))));
};
export default memo(MetadataEditorSidebarBox);
